@@ -84,7 +84,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
